A Clojure reader in Rust.
This crate tries to match the behavior of Clojure’s tools.reader as much as possible.
Re-exports
pub use de::from_str;pub use ser::to_string;pub use ser::to_string_pretty;
A Clojure reader in Rust.
This crate tries to match the behavior of Clojure’s tools.reader as much as possible.
pub use de::from_str;pub use ser::to_string;pub use ser::to_string_pretty;