Module edn

Module edn 

An EDN reader/presenter in Rust.

Implementations

  • core::fmt::Display will output valid EDN for any Edn object. Alternate formatting ({edn:#}) outputs indented EDN, with deeply nested subtrees falling back to compact formatting to bound indentation overhead.
  • With the unstable feature enabled, TryFrom<parse::Node> implemented for Edn will convert the Node into an Edn

Differences from Clojure

  • Escape characters are not escaped.

Enums

Edn

Functions

read
Reads the first object from the &str and the remaining unread &str.
read_string
Reads one object from the &str.