Module parse

Module parse 

An EDN syntax parser in Rust.

Structs

Discard
A discarded form containing the node that was discarded
Node
Concrete EDN syntax tree.
Position
SourceReader
A string-slice reader that records how much of the slice has been read
Span

Enums

NodeKind
Possible kinds of an EDN node

Functions

parse
Parse a single Node from a SourceReader, consuming that form.
parse_as_edn
Parse the first EDN form from a string and return it with the unread remainder.