Node

Struct Node 

pub struct Node<'e> {
    pub kind: NodeKind<'e>,
    pub span: Span,
    pub leading_discards: Vec<Discard<'e>>,
}
Concrete EDN syntax tree.

Parse one with parse, then convert it to an Edn with Edn::try_from.

Fields

kind: NodeKind<'e>span: Spanleading_discards: Vec<Discard<'e>>

Implementations

Source

impl<'e> Node<'e>

pub const fn no_discards(kind: NodeKind<'e>, span: Span) -> Self

Construct a Node with the given kind and span and no leading discards.

pub const fn span(&self) -> Span