SourceReader

Struct SourceReader 

pub struct SourceReader<'s> { /* private fields */ }
A string-slice reader that records how much of the slice has been read

Implementations

Source

impl<'e> SourceReader<'e>

pub fn new(source: &'e str) -> Self

pub const fn span_from(&self, marker: Position) -> Span

Span from some previously marked position to the current position of the reader

pub fn remaining(&self) -> &'e str

The portion of the source-string remaining to be read

#[cfg(feature = "unstable")]
{
  use clojure_reader::parse::{SourceReader, parse};

  let mut s = SourceReader::new("() []");
  let _ = parse(&mut s).expect("failed to parse");
  assert_eq!(s.remaining(), " []");
}
pub const fn finish(self) -> (Position, &'e str)

Finishes the source-reader, returning:

  1. the current reader position, and
  2. the original source-string.
#[cfg(feature = "unstable")]
{
  use clojure_reader::parse::{Position, SourceReader, parse};

  let mut s = SourceReader::new("() []");
  let _ = parse(&mut s).expect("failed to parse");

  let (pos, slice) = s.finish();
  assert_eq!(
      pos,
      Position {
          line: 1,
          column: 3,
          ptr: 2
      }
  );
  assert_eq!(slice, "() []");
  assert_eq!(&slice[pos.ptr..], " []");
}